@@ -14,12 +14,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import flask
-from oslo_log import log as logging
 
 from designate.central import rpcapi as central_rpcapi
 
 
-LOG = logging.getLogger(__name__)
 central_api = central_rpcapi.CentralAPI()
 blueprint = flask.Blueprint('quotas', __name__)
 
